@@ -240,7 +240,7 @@ public:
     QVariant getDefault() const;
 
 protected:
-    explicit KConfigSkeletonItem(KConfigSkeletonItemPrivate &dd, const QString &_group, const QString &_key);
+    KCONFIGCORE_NO_EXPORT explicit KConfigSkeletonItem(KConfigSkeletonItemPrivate &dd, const QString &_group, const QString &_key);
 
     /**
      * Sets mIsImmutable to @c true if mKey in config is immutable.
@@ -458,6 +458,8 @@ public:
     void setProperty(const QVariant &p) override;
     bool isEqual(const QVariant &p) const override;
     QVariant property() const override;
+    QVariant minValue() const override;
+    QVariant maxValue() const override;
     void setDefault() override;
     void swapDefault() override;
     // KF6 TODO - fix this
@@ -763,9 +765,6 @@ public:
         qint64 mMin;
         qint64 mMax;
     };
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    typedef KCONFIGCORE_DEPRECATED_VERSION(5, 0, "Use ItemLongLong") ItemLongLong ItemInt64;
-#endif
 
     /**
      * Class for handling enums.
@@ -794,13 +793,8 @@ public:
         /** @copydoc KConfigSkeletonItem::writeConfig(KConfig*) */
         void writeConfig(KConfig *config) override;
 
-        // Source compatibility with 4.x
-        // TODO KF6 remove
-        typedef Choice Choice2;
-        QList<Choice> choices2() const;
-
         /**
-         * Returns the value for for the choice with the given @p name
+         * Returns the value for the choice with the given @p name
          */
         QString valueForChoice(const QString &name) const;
 
@@ -892,9 +886,6 @@ public:
         quint64 mMin;
         quint64 mMax;
     };
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    typedef KCONFIGCORE_DEPRECATED_VERSION(5, 0, "Use ItemULongLong") ItemULongLong ItemUInt64;
-#endif
 
     /**
      * Class for handling a floating point preference item.
@@ -958,6 +949,28 @@ public:
         QVariant property() const override;
     };
 
+    /**
+     * Class for handling a QRectF preferences item.
+     */
+    class KCONFIGCORE_EXPORT ItemRectF : public KConfigSkeletonGenericItem<QRectF>
+    {
+    public:
+        /** @copydoc KConfigSkeletonGenericItem::KConfigSkeletonGenericItem */
+        ItemRectF(const QString &_group, const QString &_key, QRectF &reference, const QRectF &defaultValue = QRectF());
+
+        /** @copydoc KConfigSkeletonItem::readConfig(KConfig*) */
+        void readConfig(KConfig *config) override;
+
+        /** @copydoc KConfigSkeletonItem::setProperty(const QVariant&) */
+        void setProperty(const QVariant &p) override;
+
+        /** @copydoc KConfigSkeletonItem::isEqual(const QVariant &) const */
+        bool isEqual(const QVariant &p) const override;
+
+        /** @copydoc KConfigSkeletonItem::property() */
+        QVariant property() const override;
+    };
+
     /**
      * Class for handling a QPoint preferences item.
      */
@@ -980,6 +993,28 @@ public:
         QVariant property() const override;
     };
 
+    /**
+     * Class for handling a QPointF preferences item.
+     */
+    class KCONFIGCORE_EXPORT ItemPointF : public KConfigSkeletonGenericItem<QPointF>
+    {
+    public:
+        /** @copydoc KConfigSkeletonGenericItem::KConfigSkeletonGenericItem */
+        ItemPointF(const QString &_group, const QString &_key, QPointF &reference, const QPointF &defaultValue = QPointF());
+
+        /** @copydoc KConfigSkeletonItem::readConfig(KConfig*) */
+        void readConfig(KConfig *config) override;
+
+        /** @copydoc KConfigSkeletonItem::setProperty(const QVariant&) */
+        void setProperty(const QVariant &p) override;
+
+        /** @copydoc KConfigSkeletonItem::isEqual(const QVariant &) const */
+        bool isEqual(const QVariant &p) const override;
+
+        /** @copydoc KConfigSkeletonItem::property() */
+        QVariant property() const override;
+    };
+
     /**
      * Class for handling a QSize preferences item.
      */
@@ -1002,6 +1037,28 @@ public:
         QVariant property() const override;
     };
 
+    /**
+     * Class for handling a QSizeF preferences item.
+     */
+    class KCONFIGCORE_EXPORT ItemSizeF : public KConfigSkeletonGenericItem<QSizeF>
+    {
+    public:
+        /** @copydoc KConfigSkeletonGenericItem::KConfigSkeletonGenericItem */
+        ItemSizeF(const QString &_group, const QString &_key, QSizeF &reference, const QSizeF &defaultValue = QSizeF());
+
+        /** @copydoc KConfigSkeletonItem::readConfig(KConfig*) */
+        void readConfig(KConfig *config) override;
+
+        /** @copydoc KConfigSkeletonItem::setProperty(const QVariant&) */
+        void setProperty(const QVariant &p) override;
+
+        /** @copydoc KConfigSkeletonItem::isEqual(const QVariant &) const */
+        bool isEqual(const QVariant &p) const override;
+
+        /** @copydoc KConfigSkeletonItem::property() */
+        QVariant property() const override;
+    };
+
     /**
      * Class for handling a QDateTime preferences item.
      */
@@ -1150,18 +1207,6 @@ public:
      */
     void load();
 
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * @deprecated since 5.0, call load() instead (to reload from disk) or just read()
-     * if the underlying KConfig object is already up-to-date.
-     */
-    KCONFIGCORE_DEPRECATED_VERSION(5, 0, "Use KCoreConfigSkeleton::load() or KCoreConfigSkeleton::read()")
-    void readConfig()
-    {
-        load();
-    }
-#endif
-
     /**
      * Read preferences from the KConfig object.
      * This method assumes that the KConfig object was previously loaded,
@@ -1264,7 +1309,7 @@ public:
      * Register a property item of type QVariant.
      *
      * @note The following QVariant types are allowed:
-     * String, StringList, Font, Point, Rect, Size,
+     * String, StringList, Font, Point, PointF, Rect, RectF, Size, SizeF,
      * Color, Int, UInt, Bool, Double, DateTime and Date.
      *
      * @param name Name used to identify this setting. Names must be unique.
@@ -1328,14 +1373,6 @@ public:
      */
     ItemLongLong *addItemLongLong(const QString &name, qint64 &reference, qint64 defaultValue = 0, const QString &key = QString());
 
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * @deprecated Since 5.0, use addItemLongLong().
-     */
-    KCONFIGCORE_DEPRECATED_VERSION(5, 0, "Use KCoreConfigSkeleton::addItemLongLong(...)")
-    ItemLongLong *addItemInt64(const QString &name, qint64 &reference, qint64 defaultValue = 0, const QString &key = QString());
-#endif
-
     /**
      * Register an item of type @c quint64.
      *
@@ -1349,14 +1386,6 @@ public:
      */
     ItemULongLong *addItemULongLong(const QString &name, quint64 &reference, quint64 defaultValue = 0, const QString &key = QString());
 
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * @deprecated Since 5.0, use addItemULongLong().
-     */
-    KCONFIGCORE_DEPRECATED_VERSION(5, 0, "Use KCoreConfigSkeleton::addItemULongLong(...)")
-    ItemULongLong *addItemUInt64(const QString &name, quint64 &reference, quint64 defaultValue = 0, const QString &key = QString());
-#endif
-
     /**
      * Register an item of type @c double.
      *
@@ -1383,6 +1412,19 @@ public:
      */
     ItemRect *addItemRect(const QString &name, QRect &reference, const QRect &defaultValue = QRect(), const QString &key = QString());
 
+    /**
+     * Register an item of type QRectF.
+     *
+     * @param name Name used to identify this setting. Names must be unique.
+     * @param reference Pointer to the variable, which is set by readConfig()
+     * calls and read by save() calls.
+     * @param defaultValue Default value, which is used when the config file
+     * does not yet contain the key of this item.
+     * @param key Key used in config file. If @p key is a null string, @p name is used as key.
+     * @return The created item
+     */
+    ItemRectF *addItemRectF(const QString &name, QRectF &reference, const QRectF &defaultValue = QRectF(), const QString &key = QString());
+
     /**
      * Register an item of type QPoint.
      *
@@ -1396,6 +1438,19 @@ public:
      */
     ItemPoint *addItemPoint(const QString &name, QPoint &reference, const QPoint &defaultValue = QPoint(), const QString &key = QString());
 
+    /**
+     * Register an item of type QPointF.
+     *
+     * @param name Name used to identify this setting. Names must be unique.
+     * @param reference Pointer to the variable, which is set by readConfig()
+     * calls and read by save() calls.
+     * @param defaultValue Default value, which is used when the config file
+     * does not yet contain the key of this item.
+     * @param key Key used in config file. If @p key is a null string, @p name is used as key.
+     * @return The created item
+     */
+    ItemPointF *addItemPointF(const QString &name, QPointF &reference, const QPointF &defaultValue = QPointF(), const QString &key = QString());
+
     /**
      * Register an item of type QSize.
      *
@@ -1409,6 +1464,19 @@ public:
      */
     ItemSize *addItemSize(const QString &name, QSize &reference, const QSize &defaultValue = QSize(), const QString &key = QString());
 
+    /**
+     * Register an item of type QSizeF.
+     *
+     * @param name Name used to identify this setting. Names must be unique.
+     * @param reference Pointer to the variable, which is set by readConfig()
+     * calls and read by save() calls.
+     * @param defaultValue Default value, which is used when the config file
+     * does not yet contain the key of this item.
+     * @param key Key used in config file. If @p key is a null string, @p name is used as key.
+     * @return The created item
+     */
+    ItemSizeF *addItemSizeF(const QString &name, QSizeF &reference, const QSizeF &defaultValue = QSizeF(), const QString &key = QString());
+
     /**
      * Register an item of type QDateTime.
      *
@@ -1522,17 +1590,6 @@ public Q_SLOTS:
      */
     bool save();
 
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * @deprecated since 5.0, call save() instead.
-     */
-    KCONFIGCORE_DEPRECATED_VERSION(5, 0, "Use KCoreConfigSkeleton::save()")
-    void writeConfig()
-    {
-        save();
-    }
-#endif
-
 Q_SIGNALS:
     /**
      * This signal is emitted when the configuration change.
@@ -1571,27 +1628,11 @@ protected:
      */
     virtual bool usrSave();
 
-#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 0)
-    /**
-     * @deprecated since 5.0, override usrRead instead.  This method is still called from usrRead
-     * for compatibility.
-     */
-    KCONFIGCORE_DEPRECATED_VERSION(5, 0, "Override KCoreConfigSkeleton::usrRead()")
-    virtual void usrReadConfig();
-#endif
-
-#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 0)
-    /**
-     * @deprecated since 5.0, override usrSave instead.  This method is still called from usrSave
-     * for compatibility.
-     */
-    KCONFIGCORE_DEPRECATED_VERSION(5, 0, "Override KCoreConfigSkeleton::usrSave()")
-    virtual bool usrWriteConfig();
-#endif
-
 private:
     KCoreConfigSkeletonPrivate *const d;
     friend class KConfigSkeleton;
 };
 
+Q_DECLARE_TYPEINFO(KCoreConfigSkeleton::ItemEnum::Choice, Q_RELOCATABLE_TYPE);
+
 #endif
